@@ -1,4 +1,4 @@
-/* $Id: xfce-fileutils.c 21068 2006-04-18 21:35:22Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -13,10 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -90,12 +90,11 @@ xfce_mkdirhier (const gchar *whole_path,
         last = 1;
       else if (p[0] != '/')
         continue;
+      else if (p[1] == '\0')
+        last = 1;
 
       *p = '\0';
 
-      if (p[1] == '\0')
-        last = 1;
-
       if (first)
         {
           /*
