@@ -13,10 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA
  */
 
 #if !defined(LIBXFCE4UTIL_INSIDE_LIBXFCE4UTIL_H) && !defined(LIBXFCE4UTIL_COMPILATION)
@@ -30,19 +30,21 @@
 
 #include <libxfce4util/debug.h>
 
+G_BEGIN_DECLS
+
 const gchar* xfce_version_string (void) G_GNUC_PURE;
 
 const gchar* xfce_get_homedir    (void) G_GNUC_PURE;
 
 gchar*       xfce_get_homefile_r (gchar *buffer,
-                                  size_t length, 
+                                  size_t length,
                                   const gchar *format,
                                   ...);
 
 const gchar* xfce_get_userdir    (void) G_GNUC_PURE;
 
 gchar*       xfce_get_userfile_r (gchar *buffer,
-                                  size_t length, 
+                                  size_t length,
                                   const gchar *format,
                                   ...);
 
@@ -56,10 +58,10 @@ gchar*       xfce_get_userfile_r (gchar *buffer,
 
 #elif defined(G_HAVE_GNUC_VARARGS)
 
-#define xfce_get_homefile(first_element...)	               \
+#define xfce_get_homefile(first_element...)                \
   (g_build_filename (xfce_get_homedir (), ## first_element))
 
-#define xfce_get_userfile(first_element...)	               \
+#define xfce_get_userfile(first_element...)                \
   (g_build_filename (xfce_get_userdir (), ## first_element))
 
 #else
@@ -94,4 +96,6 @@ void    xfce_unsetenv         (const gchar *name);
 gchar*  xfce_expand_variables (const gchar *command,
                                gchar      **envp) G_GNUC_MALLOC;
 
-#endif	/* __XFCE_MISCUTILS_H__ */
+G_END_DECLS
+
+#endif /* __XFCE_MISCUTILS_H__ */
