@@ -13,10 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -128,7 +128,7 @@ struct _Group
 
 
 
-/* because strcmp is by far the most called function in this code, 
+/* because strcmp is by far the most called function in this code,
  * we inline the comparison of the first character */
 #define str_is_equal(a,b) (*(a) != *(b) ? FALSE : strcmp ((a), (b)) == 0)
 
@@ -144,7 +144,7 @@ simple_add_group (XfceRcSimple *simple,
     if (str_is_equal (group->name, name))
       return group;
 
-  group         = _xfce_slice_new (Group);
+  group         = g_slice_new (Group);
   group->name   = g_string_chunk_insert (simple->string_chunk, name);
   group->efirst = NULL;
   group->elast  = NULL;
@@ -188,25 +188,25 @@ simple_add_entry (XfceRcSimple *simple,
         /* this point is reached when there is a .desktop file that lists a language specific key for something that had no language-neutral key yet.
            Example:
              b.desktop
-             
+
              [Desktop Entry]
              Version=1.0
              Name=xyz
              GenericName[de_AT]=Test
-             
+
            here GenericName[de_AT] will end up here.
            The previous way with g_return_val_if_fail would call an assertion failure and terminate the _whole application_(!!).
-           
+
            Saner ways to react are either just ignoring GenericName[de_AT] altogether, or, alternatively, just set the normal GenericName
            to Test too (i.e. imply GenericName=Test).
-           
+
            For now, we are just ignoring the line altogether. But we aren't assert-failing anymore and the apps dont crash anymore.
            */
         return NULL;
       }
       /* why you annoying macro, will you stop borking libxfceutil? thanks. DO NOT DO THAT: g_return_val_if_fail (locale == NULL, NULL); */
 
-      entry         = _xfce_slice_new (Entry);
+      entry         = g_slice_new (Entry);
       entry->key    = g_string_chunk_insert (simple->string_chunk, key);
       entry->value  = g_string_chunk_insert (simple->string_chunk, value);
       entry->lfirst = NULL;
@@ -263,7 +263,7 @@ simple_add_entry (XfceRcSimple *simple,
       if (G_LIKELY (lentry == NULL))
         {
           /* create new localized entry */
-          lentry         = _xfce_slice_new (LEntry);
+          lentry         = g_slice_new (LEntry);
           lentry->locale = g_string_chunk_insert (simple->string_chunk, locale);
           lentry->value  = g_string_chunk_insert (simple->string_chunk, value);
 
@@ -557,21 +557,11 @@ simple_write (XfceRcSimple *simple, const gchar *filename)
 static void
 simple_entry_free (Entry *entry)
 {
-  LEntry *lentry;
-  LEntry *next;
-
   /* release all lentries */
-  for (lentry = entry->lfirst; lentry != NULL; lentry = next)
-    {
-      /* determine the next lentry */
-      next = lentry->next;
-
-      /* release this lentry */
-      _xfce_slice_free (LEntry, lentry);
-    }
+  g_slice_free_chain (LEntry, entry->lfirst, next);
 
   /* release the entry */
-  _xfce_slice_free (Entry, entry);
+  g_slice_free (Entry, entry);
 }
 
 
@@ -593,7 +583,7 @@ simple_group_free (Group *group)
     }
 
   /* release the group */
-  _xfce_slice_free (Group, group);
+  g_slice_free (Group, group);
 }
 
 
@@ -847,11 +837,11 @@ _xfce_rc_simple_get_entries (const XfceRc *rc,
 
   if (group == NULL)
     return NULL;
-  
+
   result = g_new (gchar *, 11);
   size   = 10;
   pos    = 0;
-  
+
   for (entry = group->efirst; entry != NULL; entry = entry->next)
     {
       if (size == pos)
